@@ -16,7 +16,7 @@ Version 1.03
 
 =cut
 
-our $VERSION = '1.03';
+our $VERSION = '1.04';
 
 our $ENCODER = Sereal::Encoder->new();
 our $DECODER = Sereal::Decoder->new();
@@ -60,7 +60,7 @@ gets the decoder from options or uses the default decoder
 
 sub decoder {
     my ($self) = @_;
-    return $self->{options}{decoder} || $DECODER;
+    return $self->{options}{decoder} || ($DECODER ||= Sereal::Decoder->new());
 }
 
 =head2 encoder
@@ -71,7 +71,18 @@ gets the encoder from options or uses the default encoder
 
 sub encoder {
     my ($self) = @_;
-    return $self->{options}{encoder} || $ENCODER;
+    return $self->{options}{encoder} || ($ENCODER ||= Sereal::Encoder->new());
+}
+
+=head2
+
+Recreates global ENCODER/DECODER after thread is created
+
+=cut
+
+sub CLONE {
+    $ENCODER ||= Sereal::Encoder->new();
+    $DECODER ||= Sereal::Decoder->new();
 }
 
 =head1 AUTHOR
